@@ -86,7 +86,7 @@ sub load_by_cols {
     if ( ref($class) ) {
         ( $self, $class ) = ( $class, undef );
     } else {
-        $self = $self->new( handle => ( delete $attr{'_handle'} || undef ) );
+        $self = $class->new( handle => ( delete $attr{'_handle'} || undef ) );
     }
 
     ## Generate the cache key
@@ -182,7 +182,8 @@ sub _store (\$) {
     $MEMCACHED->set( $self->_primary_cache_key,
         {   values  => $self->{'values'},
             table   => $self->table,
-            fetched => $self->{'fetched'}
+            fetched => $self->{'fetched'},
+            raw_values => $self->{'raw_values'},
         },
         $self->_cache_config->{'cache_for_sec'}
     );
